# Tesseract endpoints

## Required endpoints

### `apply`

```{eval-rst}
.. autofunction:: tesseract_core.runtime.app_cli.apply
```

## Optional endpoints

### `jacobian`

```{eval-rst}
.. autofunction:: tesseract_core.runtime.app_cli.jacobian
```

### `jacobian_vector_product`

```{eval-rst}
.. autofunction:: tesseract_core.runtime.app_cli.jacobian_vector_product
```

### `vector_jacobian_product`

```{eval-rst}
.. autofunction:: tesseract_core.runtime.app_cli.vector_jacobian_product
```

### `abstract_eval`

```{eval-rst}
.. autofunction:: tesseract_core.runtime.app_cli.abstract_eval
```
